@@ -236,7 +236,7 @@ bool pkgOptions::setup(QList<packageInfo *> pl)
   }
 //  kDebug() << "clist=" << clist << "\n";
  
- s = i18np("%2: 1 Package","%2: %1 Packages",plist.count(),insType);
+ s = i18ncp("Used when listing how many packages are to be installed, and how many are to be uninstalled.  The argument on the left is a translation of Install or Uninstall respectively.", "%2: 1 Package","%2: %1 Packages",plist.count(),insType);
  title->setText(s);
 // kDebug() << "plist=" << plist << "\n";
 
