@@ -1,5 +1,4 @@
-/* rpmInterface.h
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -17,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -28,17 +27,9 @@
 #ifndef RPM_IFACE_H
 #define RPM_IFACE_H
 
-#include "../config.h"
-
-
-#include <qptrlist.h>
-
 #include "packageInfo.h"
 #include "pkgInterface.h"
 
-class KDir;
-class cacheObj;
-
 class RPM : public pkgInterface
 {
  Q_OBJECT
@@ -50,7 +41,6 @@ public:
   bool isType(char *buf, const QString &fname);
 
   packageInfo *getPackageInfo(char mode, const QString &name, const QString &version);
-  QStringList getFileList(packageInfo *p);
   QStringList getChangeLog(packageInfo *p);
 
   bool filesTab(packageInfo *p);
@@ -58,55 +48,31 @@ public:
 
   bool changeTab(packageInfo *p);
   // If change log tab is to be enabled
+  
+  void getIFileList( packageInfo *p );
+  void getFFileList( packageInfo *p );
+  
+  packageInfo *getPackageInfo( const QString &name);
+  packageInfo *getFPackageInfo( const QString &name);
 
   QStringList depends(const QString &name, int src);
   QStringList verify(packageInfo *p, const QStringList &files);
 
-  QString uninstall(int uninstallFlags, QPtrList<packageInfo> *p, bool &test);
-  QString uninstall(int uninstallFlags, packageInfo *p, bool &test);
-  QString doUninst(int uninstallFlags, const QStringList &files, bool &test);
-  QString doUninstP(int uninstallFlags, const QStringList &files, bool &test);
+  QStringList FindFile(const QString &name, bool seachAll=false);
 
-  QString install(int installFlags, QPtrList<packageInfo> *p, bool &test);
-  QString install(int installFlags, packageInfo *p, bool &test);
-  QString doinst(int installFlags, const QStringList &files, bool &test);
-  QString doinstP(int installFlags, const QStringList &files, bool &test);
-
-  QStringList FindFile(const QString &name);
-  void collectDepends(packageInfo *p, const QString &name, int src);
-  bool parseName(const QString &name, QString *n, QString *v);
-
-  QString provMap(QString p);
-
-public slots:
-  void setLocation();
-  void setAvail(LcacheObj *);
+  QString provMap(const QString &p);
 
 private:
-  packageInfo* collectInfo(QStringList &ln);
 
-  void listInstalledPackages(QPtrList<packageInfo> *pki);
-
-  QDict<QString> provides;
   bool rpmSetup;
   QStringList infoList;
 
+  QStringList getIChangeLog( packageInfo *p );
+  QStringList getUChangeLog( const QString &fn );
+
+  QString quotePath( const QString &path);
   QString packageQuery();
   
-  QStringList getIFileList(packageInfo *p);
-  QStringList getUFileList(QString fn);
-
-  QStringList getIChangeLog(packageInfo *p);
-  QStringList getUChangeLog(QString fn);
-
-  packageInfo *getIPackageInfo( QString name);
-  packageInfo *getUPackageInfo( QString name);
-
-  QString quotePath( QString path);
-
  };
 
 #endif
-
-
-
